Package: dockerfiler
Title: Easy Dockerfile Creation from R
Version: 1.0.0
Authors@R: c(
    person("Colin", "Fay", , "contact@colinfay.me", role = c("cre", "aut"),
           comment = c(ORCID = "0000-0001-7343-1846")),
    person("Vincent", "Guyader", , "vincent@thinkr.fr", role = "aut",
           comment = c(ORCID = "0000-0003-0671-9270")),
    person("Josiah", "Parry", , "josiah.parry@gmail.com", role = "aut",
           comment = c(ORCID = "0000-0001-9910-865X")),
    person("Sébastien", "Rochette", , "sebastien@thinkr.fr", role = "aut",
           comment = c(ORCID = "0000-0002-1565-9313"))
  )
Description: Build a Dockerfile straight from your R session.
    'dockerfiler' allows you to create step by step a Dockerfile, and
    provide convenient tools to wrap R code inside this Dockerfile.
License: MIT + file LICENSE
URL: https://thinkr-open.github.io/dockerfiler/,
        https://github.com/ThinkR-open/dockerfiler
BugReports: https://github.com/ThinkR-open/dockerfiler/issues
Imports: attempt (>= 0.3.1), cli (>= 2.3.0), desc (>= 1.2.0), fs (>=
        1.5.0), glue (>= 1.4.2), jsonlite (>= 1.7.2), memoise, pak (>=
        0.6.0), pkgbuild (>= 1.2.0), purrr, R6 (>= 2.5.0), remotes (>=
        2.2.0), usethis (>= 2.0.1), utils
Suggests: knitr (>= 1.31), renv, rmarkdown (>= 2.6), testthat (>=
        3.0.0), withr
VignetteBuilder: knitr
Config/fusen/version: 0.6.0
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-05-13 09:16:49 UTC; PC
Author: Colin Fay [cre, aut] (ORCID: <https://orcid.org/0000-0001-7343-1846>),
  Vincent Guyader [aut] (ORCID: <https://orcid.org/0000-0003-0671-9270>),
  Josiah Parry [aut] (ORCID: <https://orcid.org/0000-0001-9910-865X>),
  Sébastien Rochette [aut] (ORCID:
    <https://orcid.org/0000-0002-1565-9313>)
Maintainer: Colin Fay <contact@colinfay.me>
Repository: CRAN
Date/Publication: 2026-05-14 06:30:02 UTC
Built: R 4.5.2; ; 2026-05-14 09:48:16 UTC; unix
