Package: myshinyapp
Title: Example of myshinyapp
Version: 0.1.0
Authors@R: 
    c(person(given = "Sébastien",
             family = "Rochette",
             role = c("aut", "cre"),
             email = "sebastien@thinkr.fr",
             comment = c(ORCID = "0000-0002-1565-9313")),
      person(given = "ThinkR",
             role = "cph"))
Description: This is an example of description file of a shiny app for tests.
License: file LICENSE
Depends: 
    R (>= 2.10)
Imports: 
    cli,
    glue,
    golem,
    shiny,
    stats,
    utils
Suggests: 
    testthat
VignetteBuilder: 
    knitr
Config/testthat/edition: 3
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.1.1
