Package: dockerfiler
Title: Easy Dockerfile Creation from R
Version: 0.1.3.9000
Authors@R:
    c(person(given = "Colin",
             family = "Fay",
             role = c("cre", "aut"),
             email = "contact@colinfay.me",
             comment = c(ORCID = "0000-0001-7343-1846")),
      person(given = "Vincent",
             family = "Guyader",
             role = "aut",
             email = "vincent@thinkr.fr",
             comment = c(ORCID = "0000-0003-0671-9270")))
Description: Build a Dockerfile straight from your R session.
    'dockerfiler' allows you to create step by step a Dockerfile, and
    provide convenient tools to wrap R code inside this Dockerfile.
License: MIT + file LICENSE
URL: https://github.com/ColinFay/dockerfiler
BugReports: https://github.com/ColinFay/dockerfiler/issues
Imports:
    attempt (>= 0.3.1),
    glue,
    R6,
    utils,
    fs,
    cli (>= 2.3.0),
    remotes,
    desc,
    usethis,
    jsonlite,
    pkgbuild
Suggests:
    covr,
VignetteBuilder:
    knitr
Encoding: UTF-8
LazyData: true
RoxygenNote: 6.1.0
Config/testthat/edition: 3
