# Generated by roxygen2: do not edit by hand

export(Dockerfile)
export(compact_sysreqs)
export(dock_from_desc)
export(dock_from_renv)
export(docker_ignore_add)
export(get_sysreqs)
export(parse_dockerfile)
export(r)
importFrom(R6,R6Class)
importFrom(attempt,map_try_catch)
importFrom(attempt,warn_if_not)
importFrom(cli,cat_bullet)
importFrom(desc,desc_get)
importFrom(desc,desc_get_deps)
importFrom(fs,file_create)
importFrom(fs,file_exists)
importFrom(fs,path)
importFrom(glue,glue)
importFrom(jsonlite,fromJSON)
importFrom(memoise,memoise)
importFrom(pak,pkg_sysreqs)
importFrom(pkgbuild,build)
importFrom(purrr,keep_at)
importFrom(purrr,pluck)
importFrom(remotes,dev_package_deps)
importFrom(remotes,package_deps)
importFrom(usethis,use_build_ignore)
importFrom(utils,download.file)
importFrom(utils,getFromNamespace)
importFrom(utils,glob2rx)
importFrom(utils,installed.packages)
importFrom(utils,packageVersion)
