% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dockerfiler-package.R
\docType{package}
\name{dockerfiler-package}
\alias{dockerfiler}
\alias{dockerfiler-package}
\title{dockerfiler: Easy Dockerfile Creation from R}
\description{
Build a Dockerfile straight from your R session. 'dockerfiler' allows you to create step by step a Dockerfile, and provide convenient tools to wrap R code inside this Dockerfile.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://thinkr-open.github.io/dockerfiler/}
  \item \url{https://github.com/ThinkR-open/dockerfiler}
  \item Report bugs at \url{https://github.com/ThinkR-open/dockerfiler/issues}
}

}
\author{
\strong{Maintainer}: Colin Fay \email{contact@colinfay.me} (\href{https://orcid.org/0000-0001-7343-1846}{ORCID})

Authors:
\itemize{
  \item Vincent Guyader \email{vincent@thinkr.fr} (\href{https://orcid.org/0000-0003-0671-9270}{ORCID})
  \item Josiah Parry \email{josiah.parry@gmail.com} (\href{https://orcid.org/0000-0001-9910-865X}{ORCID})
  \item Sébastien Rochette \email{sebastien@thinkr.fr} (\href{https://orcid.org/0000-0002-1565-9313}{ORCID})
}

}
\keyword{internal}
