% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/compact_sysreqs.R
\name{compact_sysreqs}
\alias{compact_sysreqs}
\title{Compact Sysreqs}
\usage{
compact_sysreqs(
  pkg_installs,
  update_cmd = "apt-get update -y",
  install_cmd = "apt-get install -y",
  clean_cmd = "rm -rf /var/lib/apt/lists/*"
)
}
\arguments{
\item{pkg_installs}{pkg_sysreqs as vector, \code{pak::pkg_sysreqs} output}

\item{update_cmd}{command used to update packages, "apt-get update -y" by default}

\item{install_cmd}{command used to install packages, "apt-get install -y" by default}

\item{clean_cmd}{command used to clean package folder, "rm -rf /var/lib/apt/lists/*" by default}
}
\value{
vector of compacted command to run to install sysreqs
}
\description{
Compact Sysreqs
}
\examples{
pkg_installs <- list("apt-get install -y htop", "apt-get install -y top")
compact_sysreqs(pkg_installs)
}
