% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/parse-dockerfile.R
\name{parse_dockerfile}
\alias{parse_dockerfile}
\title{Parse a Dockerfile}
\usage{
parse_dockerfile(path)
}
\arguments{
\item{path}{path to the Dockerfile}
}
\value{
A Dockerfile object
}
\description{
Create a Dockerfile object from a Dockerfile.
}
\examples{
parse_dockerfile(system.file("Dockerfile", package = "dockerfiler"))

}
